# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/homepage/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Homepage\\": "packages/litecms/homepage/src",
            "Litecms\\Homepage\\Seeders\\": "packages/litecms/homepage/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Homepage\Providers\HomepageServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Homepage'  => Litecms\Homepage\Facades\Homepage::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Homepage\\Seeders\\HomepageTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Homepage\Providers\HomepageServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Homepage\Providers\HomepageServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Homepage\Providers\HomepageServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/homepage/{modulename}

**User**

    http://path-to-route-folder/user/homepage/{modulename}

**Public**

    http://path-to-route-folder/homepages


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/homepage/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/homepage/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/homepage/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/homepage/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/homepage/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/homepage/{modulename}/{slug}
    METHOD: GET