<?php

namespace Litecms\Homepage\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Homepage\Models\NewsAndPress;

class NewsAndPressPolicy
{

    /**
     * Determine if the given user can view the news_and_press.
     *
     * @param UserPolicyInterface $authUser
     * @param NewsAndPress $news_and_press
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, NewsAndPress $news_and_press)
    {
        if ($authUser->canDo('homepage.news_and_press.view') && $authUser->isAdmin()) {
            return true;
        }

        return $news_and_press->user_id == user_id() && $news_and_press->user_type == user_type();
    }

    /**
     * Determine if the given user can create a news_and_press.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('homepage.news_and_press.create');
    }

    /**
     * Determine if the given user can update the given news_and_press.
     *
     * @param UserPolicyInterface $authUser
     * @param NewsAndPress $news_and_press
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, NewsAndPress $news_and_press)
    {
        if ($authUser->canDo('homepage.news_and_press.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $news_and_press->user_id == user_id() && $news_and_press->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given news_and_press.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, NewsAndPress $news_and_press)
    {
        return $news_and_press->user_id == user_id() && $news_and_press->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given news_and_press.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, NewsAndPress $news_and_press)
    {
        if ($authUser->canDo('homepage.news_and_press.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given news_and_press.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, NewsAndPress $news_and_press)
    {
        if ($authUser->canDo('homepage.news_and_press.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
