<?php

namespace Litecms\Homepage\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Homepage\Models\Promo;

class PromoPolicy
{

    /**
     * Determine if the given user can view the promo.
     *
     * @param UserPolicyInterface $authUser
     * @param Promo $promo
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Promo $promo)
    {
        if ($authUser->canDo('homepage.promo.view') && $authUser->isAdmin()) {
            return true;
        }

        return $promo->user_id == user_id() && $promo->user_type == user_type();
    }

    /**
     * Determine if the given user can create a promo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('homepage.promo.create');
    }

    /**
     * Determine if the given user can update the given promo.
     *
     * @param UserPolicyInterface $authUser
     * @param Promo $promo
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Promo $promo)
    {
        if ($authUser->canDo('homepage.promo.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $promo->user_id == user_id() && $promo->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given promo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Promo $promo)
    {
        return $promo->user_id == user_id() && $promo->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given promo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Promo $promo)
    {
        if ($authUser->canDo('homepage.promo.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given promo.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Promo $promo)
    {
        if ($authUser->canDo('homepage.promo.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
