<?php

namespace Litecms\Homepage\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Homepage\Homepages;

class HomepageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'homepage');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'homepage');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\Homepage\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Homepage\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\Homepage\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\Homepage\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.homepage', function($app)
        {
            return $this->app->make(Homepages::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Carousel to repository
        $this->app->bind(
            'Litecms\Homepage\Interfaces\CarouselRepositoryInterface',
            \Litecms\Homepage\Repositories\Eloquent\CarouselRepository::class
        );        // Bind Catalog to repository
        $this->app->bind(
            'Litecms\Homepage\Interfaces\CatalogRepositoryInterface',
            \Litecms\Homepage\Repositories\Eloquent\CatalogRepository::class
        );        // Bind NewsAndPress to repository
        $this->app->bind(
            'Litecms\Homepage\Interfaces\NewsAndPressRepositoryInterface',
            \Litecms\Homepage\Repositories\Eloquent\NewsAndPressRepository::class
        );        // Bind Promo to repository
        $this->app->bind(
            'Litecms\Homepage\Interfaces\PromoRepositoryInterface',
            \Litecms\Homepage\Repositories\Eloquent\PromoRepository::class
        );
    }


    /**
     * Merges user's and homepage's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.homepage'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\Homepage\Commands\Homepage::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.homepage'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/homepage.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/homepage')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/homepage')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
